import json
import os
import sys
from datetime import datetime

from pydantic_glue import convert


def cli() -> None:
    if len(sys.argv) != 3:
        print(f"Usage: {sys.argv[0]} <module file> <class name>", file=sys.stderr)
        sys.exit(1)

    module_file = sys.argv[1].replace(".py", "")
    class_name = sys.argv[2]

    sys.path.append(os.path.dirname(module_file))

    imported = __import__(os.path.basename(module_file))
    imported = getattr(imported, class_name)
    input_schema = json.dumps(imported.model_json_schema())
    converted = convert(input_schema)
    output = {
        "//": f"Generated by pydantic-glue at {datetime.now()}. DO NOT EDIT",
        "columns": {k: v for (k, v) in converted},
    }

    print(json.dumps(output, indent=2))
